#!/usr/bin/python3
"""
// © University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road,
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Nikolay Stanchev
//      Created Date :          02-07-2018
//      Created for Project :   FLAME
"""


class _MonitoringProcess:
    """
    Container-like class used to store key value pairs between graph pipelines request identifiers and process identifiers.
    The class is declared as "pseudo-private" and is ought to be initialised only in this module and exposed as a singleton.
    This class mimics the interfaces of the other model classes.
    """

    def __init__(self):

        self.__pipelines = {}

    def add(self, instance):
        """
        Adds a new key-value pair to the container representing a request ID mapped to a PID.

        :param instance: JSON representation of key value pair - e.g. {"request_id": <reequest uuid>, "process_id": <process ID>}
        """

        self.__pipelines[instance["request_id"]] = instance["process_id"]

    def delete(self, request_id):
        """
        Deletes a key-value pair from the container representing a request ID mapped to a PID.

        :param request_id: the request UUID
        """

        self.__pipelines.pop(request_id)

    def get(self, request_id):
        """
        Gets the data associated with a request identifier - currently the data is just the process identifier.

        :param request_id: the request identifier to check

        :return: the PID for this request ID or None if it doesn't exist
        """

        return self.__pipelines.get(request_id)

    def exists(self, request_id):
        """
        Checks if a request ID is associated to a given process ID

        :param request_id: the request identifier to check

        :return: True or False
        """

        return request_id in self.__pipelines


# Only initialise the class here, this instance is imported in models/__init__.py so that it behaves like the other ORM models,
# the container's interface mimics the interface of the other ORM models
MonitoringProcess = _MonitoringProcess()
